==> CoolWorld-0.2.tar.gz: CoolWorld-0.2/CoolWorld/__init__.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-

"""Package initialization module.

Current implementation allows to get all class defs (except those of
tkinter_ui module) by simply importing package name.

Example:

    import CoolWorld
    world = CoolWorld.World2D()
    player = CoolWorld.WorldPlayer2D(world, name="player")
    enemy = CoolWorld.WorldSprite2D(world, name="enemy")
    view = CoolWorld.WorldView(world, name="view")
    world.run()

Notice: it is fancier to use:

    from CoolWorld import game
    world = game.World2D()
    player = game.WorldPlayer2D(world, name="player")
    enemy = game.WorldSprite2D(world, name="enemy")
    view = game.WorldView(world, name="view")
    world.run()
"""

"""
    The MIT License (MIT)

    Copyright (c) 2015 Raphaël SEBAN

    Permission is hereby granted, free of charge, to any person
    obtaining a copy of this software and associated documentation
    files (the "Software"), to deal in the Software without
    restriction, including without limitation the rights to use, copy,
    modify, merge, publish, distribute, sublicense, and/or sell copies
    of the Software, and to permit persons to whom the Software is
    furnished to do so, subject to the following conditions:

    The above copyright notice and this permission notice shall be
    included in all copies or substantial portions of the Software.

    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
    EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
    MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
    NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
    BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
    ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
    CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
    SOFTWARE.
"""

try:
    from .game import *
except:
    from game import *
# end try

==> CoolWorld-0.2.1.tar.gz: CoolWorld-0.2.1/CoolWorld/__init__.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-

"""Package initialization module.

Current implementation allows to get all class defs (except those of
tkinter_ui module) by simply importing package name.

Example::

    import CoolWorld
    world = CoolWorld.World2D()
    player = CoolWorld.WorldPlayer2D(world, name="player")
    enemy = CoolWorld.WorldSprite2D(world, name="enemy")
    view = CoolWorld.WorldView(world, name="view")
    world.run()

Notice: it is fancier to use::

    from CoolWorld import game
    world = game.World2D()
    player = game.WorldPlayer2D(world, name="player")
    enemy = game.WorldSprite2D(world, name="enemy")
    view = game.WorldView(world, name="view")
    world.run()
"""

"""
    The MIT License (MIT)

    Copyright (c) 2015 Raphaël SEBAN

    Permission is hereby granted, free of charge, to any person
    obtaining a copy of this software and associated documentation
    files (the "Software"), to deal in the Software without
    restriction, including without limitation the rights to use, copy,
    modify, merge, publish, distribute, sublicense, and/or sell copies
    of the Software, and to permit persons to whom the Software is
    furnished to do so, subject to the following conditions:

    The above copyright notice and this permission notice shall be
    included in all copies or substantial portions of the Software.

    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
    EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
    MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
    NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
    BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
    ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
    CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
    SOFTWARE.
"""

try:
    from .game import *
except:
    from game import *
# end try
